@@ -93,7 +93,7 @@ type NodeMaintainer interface {
 // Loggable represents resources with logs.
 type Loggable interface {
 	// TaiLogs streams resource logs.
-	TailLogs(ctx context.Context, c LogChan, opts *LogOptions) error
+	TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, error)
 }
 
 // Describer describes a resource.
